from pathlib import Path

from setuptools import find_packages, setup

# Read README.md for long description
readme_file = Path(__file__).parent / "Memory LLM" / "README.md"
long_description = ""
if readme_file.exists():
    long_description = readme_file.read_text(encoding="utf-8")
else:
    # Fallback to relative path from current directory
    readme_file = Path("Memory LLM") / "README.md"
    if readme_file.exists():
        long_description = readme_file.read_text(encoding="utf-8")
    else:
        long_description = "A powerful Memory LLM library with Hierarchical Memory and Multi-Backend support"

setup(
    name="mem-llm",
    version="2.3.6",
    description="A powerful Memory LLM library with Hierarchical Memory and Multi-Backend support",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Emre Q",
    packages=find_packages(where="Memory LLM"),
    package_dir={"": "Memory LLM"},
    install_requires=[
        "ollama",
        "chromadb",
        "sentence-transformers",
        "pytest",
        "pyyaml",
        "networkx",
        "psutil",
    ],
    python_requires=">=3.10",
)
